@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "docker" "2.5.0"
+(define-package "docker" "20251028.1026"
   "Interface to Docker."
   '((aio       "1.0")
     (dash      "2.19.1")
@@ -8,8 +8,8 @@
     (tablist   "1.1")
     (transient "0.4.3"))
   :url "https://github.com/Silex/docker.el"
-  :commit "916686b86e83a3bd2281fbc5e6f98962aa747429"
-  :revdesc "2.5.0-0-g916686b86e83"
+  :commit "375e0ed45bb1edc655d9ae2943a09864bec1fcba"
+  :revdesc "375e0ed45bb1"
   :keywords '("filename" "convenience")
   :authors '(("Philippe Vaucher" . "philippe.vaucher@gmail.com"))
   :maintainers '(("Philippe Vaucher" . "philippe.vaucher@gmail.com")))
